@@ -32,7 +32,7 @@ A Flake8 plugin and pre-commit hook which checks to ensure modules have defined
 # stdlib
 import ast
 import sys
-from typing import Any, Generator, List, Tuple, Type, Union
+from typing import Any, Generator, List, Set, Tuple, Type, Union
 
 # 3rd party
 from consolekit.terminal_colours import Fore
@@ -45,7 +45,7 @@ from flake8_dunder_all.utils import get_docstring_lineno, mark_text_ranges
 __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020 Dominic Davis-Foster"
 __license__: str = "MIT"
-__version__: str = "0.1.2"
+__version__: str = "0.1.3"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __all__ = ["Visitor", "Plugin", "check_and_add_all", "DALL000"]
@@ -64,11 +64,12 @@ class Visitor(ast.NodeVisitor):
 
 	found_all: bool  #: Flag to indicate a ``__all__`` variable has been found in the AST.
 	last_import: int  #: The lineno of the last top-level import
-	members: List[str]  #: List of functions and classed defined in the AST
+	members: Set[str]  #: List of functions and classed defined in the AST
+	use_endlineno: bool
 
 	def __init__(self, use_endlineno: bool = False) -> None:
 		self.found_all = False
-		self.members: List[str] = []
+		self.members = set()
 		self.last_import = 0
 		self.use_endlineno = use_endlineno
 
@@ -91,8 +92,30 @@ class Visitor(ast.NodeVisitor):
 		:param node: The node being visited.
 		"""
 
-		if not node.name.startswith("_"):
-			self.members.append(node.name)
+		decorators = []
+
+		for deco in node.decorator_list:
+			if isinstance(deco, ast.Name):
+				decorators.append(deco.id)
+			elif isinstance(deco, ast.Attribute):
+				parts = [deco.attr]
+
+				# last_part = deco.value
+				#
+				# while True:
+				# 	if isinstance(last_part, ast.Attribute):
+				# 		parts.append(last_part.attr)
+				# 		last_part = last_part.value
+				# 	elif isinstance(last_part, ast.Name):
+				# 		parts.append(last_part.id)
+				# 		break
+				# 	else:
+				# 		break
+
+				decorators.append('.'.join(reversed(parts)))
+
+		if not node.name.startswith('_') and "overload" not in decorators:
+			self.members.add(node.name)
 
 	def visit_FunctionDef(self, node: ast.FunctionDef):
 		"""
@@ -229,25 +252,25 @@ def check_and_add_all(filename: PathPlus, quote_type: str = '"') -> int:
 	else:
 		docstring_start = (get_docstring_lineno(tree) or 0) - 1
 		docstring = ast.get_docstring(tree, clean=False) or ''
-		docstring_end = len(docstring.split("\n")) + docstring_start
+		docstring_end = len(docstring.split('\n')) + docstring_start
 
 		insertion_position = max(docstring_end, visitor.last_import) + 1
 
 		if not visitor.members:
 			return 0
 
-		members = repr(visitor.members).replace(bad_quote, quote_type)
+		members = repr(sorted(visitor.members)).replace(bad_quote, quote_type)
 
-		lines = filename.read_text().split("\n")
+		lines = filename.read_text().split('\n')
 
 		# Ensure there don't end up too many lines
 		if lines[insertion_position].strip():
-			lines.insert(insertion_position, "\n")
+			lines.insert(insertion_position, '\n')
 		else:
-			lines.insert(insertion_position, "")
+			lines.insert(insertion_position, '')
 
 		lines.insert(insertion_position, f"__all__ = {members}")
 
-		filename.write_clean("\n".join(lines))
+		filename.write_clean('\n'.join(lines))
 
 		return 1
